@@ -7,6 +7,7 @@ from multiprocessing.pool import ThreadPool
 import numpy as np
 import pandas as pd
 from Bio.Phylo import NewickIO, write
+from Bio.Phylo.NewickIO import StringIO
 from ete3 import Tree
 
 from pastml.models.rate_matrix import CUSTOM_RATES, load_custom_rates
@@ -30,7 +31,7 @@ from pastml.visualisation.cytoscape_manager import visualize, TIMELINE_SAMPLED,
 from pastml.visualisation.itol_manager import generate_itol_annotations
 from pastml.visualisation.tree_compressor import REASONABLE_NUMBER_OF_TIPS
 
-PASTML_VERSION = '1.9.33'
+PASTML_VERSION = '1.9.34'
 
 warnings.filterwarnings("ignore", append=True)
 
@@ -288,10 +289,10 @@ def acr(forest, df=None, columns=None, column2states=None, prediction_method=MPP
                 if tau is None and tau_p is not None:
                     tau = tau_p
                 if freqs is not None and model not in {F81, HKY, CUSTOM_RATES}:
-                    logging.warning('Some frequencies were specified in the parameter file, '
-                                    'but the selected model ({}) ignores them. '
-                                    'Use F81 (or HKY for nucleotide characters only) '
-                                    'for taking user-specified frequencies into account.'.format(model))
+                    logger.warning('Some frequencies were specified in the parameter file, '
+                                   'but the selected model ({}) ignores them. '
+                                   'Use F81 (or HKY for nucleotide characters only) '
+                                   'for taking user-specified frequencies into account.'.format(model))
             optimise_sf = not sf or reoptimise
             if not sf:
                 sf = 1. / tree_stats[0]
@@ -341,10 +342,9 @@ def acr(forest, df=None, columns=None, column2states=None, prediction_method=MPP
             else:
                 frequencies = np.ones(n, dtype=np.float64) / n
             character2settings[character] = [prediction_method, model, states,
-                                             [frequencies, kappa, sf, tau, rate_matrix], \
+                                             [frequencies, kappa, sf, tau, rate_matrix],
                                              [optimise_frequencies, optimise_kappa, optimise_sf, optimise_tau,
-                                              frequency_smoothing], \
-                                             observed_frequencies]
+                                              frequency_smoothing], observed_frequencies]
         else:
             raise ValueError('Method {} is unknown, should be one of ML ({}), one of MP ({}) or {}'
                              .format(prediction_method, ', '.join(ML_METHODS), ', '.join(MP_METHODS), COPY))
@@ -679,14 +679,14 @@ def pastml_pipeline(tree, data=None, data_sep='\t', id_index=0,
     new_tree = os.path.join(work_dir, get_named_tree_file(tree))
     features = [DATE, DATE_CI] + list(column2states.keys())
     clear_extra_features(roots, features)
-    nwks = [root.write(format_root_node=True, format=3, features=features) for root in roots]
+    nwks = '\n'.join([root.write(format_root_node=True, format=3, features=features) for root in roots])
     with open(new_tree, 'w+') as f:
-        f.write('\n'.join(nwks))
+        f.write(nwks)
     try:
         nexus = new_tree.replace('.nwk', '.nexus')
         if '.nexus' not in nexus:
             nexus = '{}.nexus'.format(nexus)
-        write(NewickIO.parse(nwks), nexus, 'nexus')
+        write(NewickIO.parse(StringIO(nwks)), nexus, 'nexus')
         with open(nexus, 'r') as f:
             nexus_str = f.read().replace('&&NHX:', '&')
             for feature in features:
@@ -879,17 +879,23 @@ def _validate_input(tree_nwk, columns=None, name_column=None, data=None, data_se
             column2states[c] |= {_ for _ in df[c].unique() if pd.notnull(_) and _ != ''}
 
     num_tips = 0
+
+    column2annotated_states = defaultdict(set)
     for root in roots:
         for n in root.traverse():
             for c in columns:
                 vs = getattr(n, c, set())
                 column2states[c] |= vs
+                column2annotated_states[c] |= vs
                 if vs:
                     column2annotated[c] += 1
             if n.is_leaf():
                 num_tips += 1
 
-    c, num_annotated = min(column2annotated.items(), key=lambda _: _[1])
+    if column2annotated:
+        c, num_annotated = min(column2annotated.items(), key=lambda _: _[1])
+    else:
+        c, num_annotated = columns[0], 0
     percentage_unknown = (num_tips - num_annotated) / num_tips
     if percentage_unknown >= (.9 if not copy_only else 1):
         raise ValueError('{:.1f}% of tip annotations for character "{}" are unknown, '
@@ -901,11 +907,12 @@ def _validate_input(tree_nwk, columns=None, name_column=None, data=None, data_se
                                  else 'You tree file should contain character state annotations, '
                                       'otherwise consider specifying a metadata file.'))
 
-    c, states = min(column2states.items(), key=lambda _: len(_[1]))
-    if len(states) > num_tips * .5 and not copy_only:
-        raise ValueError('Character "{}" has {} unique states which is too much to infer on a {} with only {} tips. '
+    c, states = min(column2annotated_states.items(), key=lambda _: len(_[1]))
+    if len(states) > num_tips * .75 and not copy_only:
+        raise ValueError('Character "{}" has {} unique states annotated in this tree: {}, '
+                         'which is too much to infer on a {} with only {} tips. '
                          'Make sure the character you are analysing is discreet, and if yes use a larger tree.'
-                         .format(c, states, 'tree' if len(roots) == 1 else 'forest', num_tips))
+                         .format(c, len(states), states, 'tree' if len(roots) == 1 else 'forest', num_tips))
 
     if name_column and name_column not in columns:
         raise ValueError('The name column ("{}") should be one of those specified as columns ({}).'
